@@ -6,26 +6,31 @@ class BoundCell(object):
         self.row_number = row_number
         self.data = data
         self.row = row
-        self._style = None
+        self._cell_atts = None
+        self._value = None
 
     def __unicode__(self):
         return unicode(self.value)
 
     @property
     def value(self):
-        return self.column.get_value(self.table, self.row, row_number=self.row_number)
+        if self._value is None:
+            self._value = self.column.get_value(self.table, self.row, row_number=self.row_number)
+        return self._value
 
     def as_html(self):
         return self.column.as_html(self.table, self.row, row_number=self.row_number)
 
     @property
-    def style(self):
-        if self._style is None:
-            if self.column.cell_style and callable(self.column.cell_style):
-                self._style = self.column.cell_style(self.table, self.row, self.value)
-            else:
-                self._style = self.column.cell_style
-        return self._style
+    def html_attrs(self):
+        if self._cell_atts is None:
+            self._cell_atts = self.column.cell_html_attrs(
+                self.table,
+                self.row,
+                self.value,
+                row_number=self.row_number)
+        return self._cell_atts
+
 
 class BoundRow(object):
     def __init__(self, table, row_number, data, row):
