@@ -4,4 +4,4 @@ from .paginator import PaginatorPlugin
 from .quicksearch import QuickSearchORM
 from .actions import ActionsState, PostAction
 from .sortable import SingleSortPlugin
-from .filters import CategoryFilter
+from .filters import CategoryFilter, DropdownFilter
